@@ -154,7 +154,7 @@
 #'
 #' # Try SensAnalysisMLP
 #' trData <- nntrData
-#' NeuralSens::SensAnalysisMLP(neuralmod, trData = trData, output_name = "DEM")
+#' NeuralSens::SensAnalysisMLP(neuralmod, trData = trData, output_name = "DEM",actfunc = c("linear","sigmoid","linear"))
 #'
 #' ## Train RSNNS NNET ------------------------------------------------------------
 #' # Normalize data using RSNNS algorithms
@@ -422,7 +422,7 @@ SensAnalysisMLP.default <- function(MLP.fit,
     }
   }
 
-  TestData <- TestData[, varnames]
+  TestData <- TestData[, varnames, drop = FALSE]
   if (!is.null(preProc)) {
     TestData <- stats::predict(preProc, TestData[, varnames])
   }
@@ -443,7 +443,7 @@ SensAnalysisMLP.default <- function(MLP.fit,
   ActivationFunction <- lapply(actfunc, NeuralSens::ActFunc)
   DerActivationFunction <- lapply(deractfunc, NeuralSens::DerActFunc)
 
-  W[[1]] <- diag(ncol(TestData)+1)
+  W[[1]] <- rbind(rep(0,ncol(TestData)),diag(ncol(TestData)))
   # For each row in the TestData
   Z[[1]] <- as.matrix(TestData)
   O[[1]] <- ActivationFunction[[1]](Z[[1]])
@@ -748,7 +748,7 @@ SensAnalysisMLP.H2OMultinomialModel <- function(MLP.fit,
                           output_name = if("output_name" %in% names(args)){args$output_name}else{MLP.fit@parameters$y},
                           deractfunc = if("deractfunc" %in% names(args)){args$deractfunc}else{NULL},
                           args[!names(args) %in% c("trData","output_name","deractfunc")])
-  }
+}
 
 #' @rdname SensAnalysisMLP
 #'
@@ -910,7 +910,7 @@ SensAnalysisMLP.H2ORegressionModel <- function(MLP.fit,
                           output_name = if("output_name" %in% names(args)){args$output_name}else{MLP.fit@parameters$y},
                           deractfunc = if("deractfunc" %in% names(args)){args$deractfunc}else{NULL},
                           args[!names(args) %in% c("trData","output_name","deractfunc")])
-  }
+}
 
 
 #' @rdname SensAnalysisMLP
@@ -961,10 +961,10 @@ SensAnalysisMLP.list <- function(MLP.fit,
     # See ?neural::mlptrain to see which number correspond to which activation function
     actfunc <- c("linear",
                  ifelse(actfunc == 1, "sigmoid",
-                   ifelse(actfunc == 2, "tanh",
-                     ifelse(actfunc == 3, "Gauss",
-                       ifelse(actfunc == 4, "linear"
-                         )))))
+                        ifelse(actfunc == 2, "tanh",
+                               ifelse(actfunc == 3, "Gauss",
+                                      ifelse(actfunc == 4, "linear"
+                                      )))))
   }
 
   SensAnalysisMLP.default(finalModel,
@@ -1117,20 +1117,20 @@ SensAnalysisMLP.nn <- function(MLP.fit,
     finalModel$n <- c(finalModel$n, dim(MLP.fit$weights[[j]][[i]])[2])
     finalModel$wts <- wts
     sensitivities <- SensAnalysisMLP.default(finalModel,
-                            trData = trData,
-                            actfunc = actfun,
-                            .returnSens = TRUE,
-                            .rawSens = TRUE,
-                            sens_origin_layer = sens_origin_layer,
-                            sens_end_layer = sens_end_layer,
-                            sens_origin_input = sens_origin_input,
-                            sens_end_input = sens_end_input,
-                            preProc = preProc,
-                            terms = terms,
-                            plot = FALSE,
-                            output_name = names(trData)[names(trData) == MLP.fit$model.list$response],
-                            deractfunc = if("deractfunc" %in% names(args)){args$deractfunc}else{NULL},
-                            args[!names(args) %in% c("deractfunc")])
+                                             trData = trData,
+                                             actfunc = actfun,
+                                             .returnSens = TRUE,
+                                             .rawSens = TRUE,
+                                             sens_origin_layer = sens_origin_layer,
+                                             sens_end_layer = sens_end_layer,
+                                             sens_origin_input = sens_origin_input,
+                                             sens_end_input = sens_end_input,
+                                             preProc = preProc,
+                                             terms = terms,
+                                             plot = FALSE,
+                                             output_name = names(trData)[names(trData) == MLP.fit$model.list$response],
+                                             deractfunc = if("deractfunc" %in% names(args)){args$deractfunc}else{NULL},
+                                             args[!names(args) %in% c("deractfunc")])
     sensit[((j-1)*nrow(trData)+1):(j*nrow(trData)),,] <- sensitivities
   }
   colnames(sensit) <- finalModel$coefnames
@@ -1311,46 +1311,43 @@ SensAnalysisMLP.nnetar <- function(MLP.fit,
   for (i in 1:length(MLP.fit$model)) {
     finalModel$wts <- MLP.fit$model[[1]]$wts
     sensitivities[[i]] <-  SensAnalysisMLP.default(finalModel,
-                                              trData = trData,
-                                              actfunc = actfun,
-                                              deractfunc = if("deractfunc" %in% names(args)){args$deractfunc}else{NULL},
-                                              .returnSens = TRUE,
-                                              .rawSens = TRUE,
-                                              sens_origin_layer = sens_origin_layer,
-                                              sens_end_layer = sens_end_layer,
-                                              sens_origin_input = sens_origin_input,
-                                              sens_end_input = sens_end_input,
-                                              preProc = NULL,
-                                              terms = NULL,
-                                              plot = FALSE,
-                                              output_name = if("output_name" %in% names(args)){args$output_name}else{".outcome"})
-    sensit[((i-1)*nrow(trData)+1):(i*nrow(trData)),,] <- sensitivities[[i]]
+
+    trData = trData,
+    actfunc = actfun,
+    deractfunc = if("deractfunc" %in% names(args)){args$deractfunc}else{NULL},
+    sens_origin_layer = sens_origin_layer,
+    sens_end_layer = sens_end_layer,
+    sens_origin_input = sens_origin_input,
+    sens_end_input = sens_end_input,
+    preProc = NULL,
+    terms = NULL,
+    plot = FALSE,
+    output_name = if("output_name" %in% names(args)){args$output_name}else{".outcome"})
+    sensit[((i-1)*nrow(trData)+1):(i*nrow(trData)),,] <- sensitivities[[i]]$raw_sens
   }
 
-  colnames(sensit) <- finalModel$coefnames
+  sens <- data.frame(
+    mean = colMeans(sensit[, , 1], na.rm = TRUE),
+    std = apply(sensit[, , 1], 2, stats::sd, na.rm = TRUE),
+    meanSensSQ = colMeans(sensit[, , 1] ^ 2, na.rm = TRUE),
+    row.names = varnames
+  )
+
+  sens <- SensMLP(
+    sens,
+    sensit,
+    MLP.fit$model[[1]]$n,
+    trData,
+    varnames,
+    if("output_name" %in% names(args)){args$output_name}else{".outcome"}
+  )
 
-  sens <-
-    data.frame(
-      varNames = varnames,
-      mean = colMeans(sensit[, , 1], na.rm = TRUE),
-      std = apply(sensit[, , 1], 2, stats::sd, na.rm = TRUE),
-      meanSensSQ = colMeans(sensit[, , 1] ^ 2, na.rm = TRUE)
-    )
 
   if (plot) {
     # show plots if required
-    NeuralSens::SensitivityPlots(sens,der = sensit[,,1])
-  }
-
-  if (.returnSens) {
-    if(!.rawSens) {
-      # Check if there are more than one output
-      return(sens)
-    } else {
-      # Return sensitivities without processing
-      return(sensit)
-    }
+    NeuralSens::SensitivityPlots(sens)
   }
+  return(sens)
 }
 
 #' @rdname SensAnalysisMLP
